@@ -3,9 +3,12 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub a { }
+sub b { }
+sub c { }
+sub d { }
 
 1;
 __END__
